import React from 'react'
import injectSheet, {createTheming} from 'react-jss'

const theming = createTheming('__DEFAULT_BUTTON__')
const { ThemeProvider } = theming

const styles = theme => ({
  button: {
    outline: 0,
    border: 0,
    cursor: 'pointer',
    height: '40px',
    lineHeight: '40px',
    padding: '0 14px',
    borderRadius: '4px',
    fontSize: '16px',
    fontWeight: 600,
    textTransform: 'uppercase',
    letterSpacing: '.025em',
    textDecoration: 'none',
    color: theme.color,
    backgroundColor: theme.backgroundColor,
    boxShadow: theme.boxShadow,
    '&:hover': {
      ...theme.hover
    }
  }
})

function Button(props) {
  const {
    children,
    classes,
    theme,
    ...rest
  } = props;

  return(
    <button {...rest} className={classes.button}>{children}</button>
  )
}

Button.defaultProps = {
  style: {},
}

const ButtonWithTheme = injectSheet(styles, { theming })(Button)

function ButtonWrapper(props) {
  const {
    theme,
    primary,
    secondary,
    ...rest
  } = props;

  const primaryTheme = {
    color: '#fff',
    backgroundColor: 'rgba(39,174,96,1)',
    boxShadow: '0 1px 3px 0 rgba(0,0,0,.15)',
    hover: {
      transform: 'translate3D(0,-1px,0)',
      boxShadow: '0 2px 5px 0 rgba(0,0,0,.15)'
    },
    ...theme
  }

  const secondaryTheme = {
    color: 'rgba(23,42,58,1)',
    backgroundColor: '#fff',
    boxShadow: '0 1px 3px 0 rgba(0,0,0,.15)',
    hover: {
      transform: 'translate3D(0,-1px,0)',
      boxShadow: '0 2px 5px 0 rgba(0,0,0,.15)'
    },
    ...theme
  }

  return (
    <ThemeProvider theme={secondary ? secondaryTheme : primaryTheme}>  
      <ButtonWithTheme {...rest} />
    </ThemeProvider>
  )
}

ButtonWrapper.defaultProps = {
  theme: {},
  primary: true,
  secondary: false
}

export default ButtonWrapper